@@ -36,7 +36,7 @@ def _auto_initialize_if_needed():
 
     # Создаем экземпляр обработчика. Он сам разберется с Redis.
     _telegram_instance = _TelegramHandler(token=token, chat_id=chat_id)
-    print("Модуль успешно авто-инициализирован.")
+    #print("Модуль успешно авто-инициализирован.")
 
 
 async def call(text: str, task_id: str):
@@ -48,20 +48,26 @@ async def call(text: str, task_id: str):
     _auto_initialize_if_needed()
     await _telegram_instance.send_message(text, task_id)
 
-
-async def ans(task_id: str) -> dict | None:
+async def ans(task_id: str) :
     """
-    Асинхронно проверяет наличие ответа для задачи с уникальным ID.
-    Возвращает словарь с информацией об ответе или None.
+    Асинхронно проверяет и возвращает ПОЛНУЮ историю ответов для задачи.
     """
     _auto_initialize_if_needed()
-    reply_data = await _telegram_instance.check_for_reply(task_id)
 
-    if reply_data:
-        answer = f"""{reply_data['text']}"""
-        pyperclip.copy(answer)
-        pyperclip.paste()
+    replies_list = await _telegram_instance.get_all_replies(task_id)
+
+    if replies_list:
+        # print(f"--- История ответов для задачи '{task_id}' (всего: {len(replies_list)}) ---")
+        last_text = ""
+        for reply in replies_list:
+            username = reply.get('username', 'N/A')
+            last_text = reply.get('text', '')
+
+
+            pyperclip.copy(last_text)
+            pyperclip.paste()
+
     else:
-        print(f"Ответа для задачи '{task_id}' пока нет.")
+        print(f"нет")
 
-    return reply_data
\ No newline at end of file
+    #return replies_list
\ No newline at end of file
